@@ -1,6 +1,6 @@
 ui <- bslib::page_sidebar(
   shinyjs::useShinyjs(),
-  title = 'praatpicture: Praat-style plots of acousic data in R',
+  title = 'praatpicture: Praat-style plots of acoustic data in R',
   sidebar = bslib::sidebar(
     bslib::accordion(
       bslib::accordion_panel(
@@ -234,6 +234,34 @@ ui <- bslib::page_sidebar(
       ),
       bslib::accordion_panel(
         'Highlighting',
+        checkboxInput('highlightBool',
+                      'Differential highlighting of parts of signals?',
+                      FALSE),
+        shinyjs::hidden(selectInput('highlightComp',
+                                    'Which signal to highlight',
+                                    choices = c('all', 'wave', 'spectrogram',
+                                                'pitch', 'formant', 'intensity'),
+                                    selected = 'all')),
+        shinyjs::hidden(textInput('highlightStart',
+                                  'Start time(s) (comma-separated)',
+                                  '0')),
+        shinyjs::hidden(textInput('highlightEnd',
+                                  'End time(s) (comma-separated)',
+                                  '0.1')),
+        shinyjs::hidden(checkboxInput('highlightTGbool',
+                                      'Use TextGrid information?',
+                                      FALSE)),
+        shinyjs::hidden(textInput('highlightTier',
+                                  'TextGrid tier')),
+        shinyjs::hidden(textInput('highlightLabel',
+                                  'Label(s) to match in TextGrid tier')),
+        shinyjs::hidden(textInput('highlightCol',
+                                  'Color(s) (comma-separated)',
+                                  'black')),
+        shinyjs::hidden(textInput('highlightDrawSize',
+                                  'Draw size')),
+        shinyjs::hidden(textInput('highlightSpeckleSize',
+                                  'Speckle size')),
         checkboxInput('arrowBool', 'Add arrow(s)?'),
         shinyjs::hidden(textInput('arrowComp',
                                   paste('Which plot component(s) should arrow(s) be',
